@@ -13,8 +13,4 @@ sub param {
 	return;
 }
 
-sub cookie {
-    return 'choc-chip';
-}
-
-1;
+1;
\ No newline at end of file
